@@ -4,10 +4,10 @@ package Game::Entities;
 use strict;
 use warnings;
 
-use Carp 'croak';
-use Data::Dumper;
-use List::Util 'all';
-use Scalar::Util 'refaddr';
+use Carp         ();
+use Data::Dumper ();
+use List::Util   ();
+use Scalar::Util ();
 
 use experimental 'signatures';
 
@@ -26,8 +26,6 @@ use constant {
     ENTITY_SHIFT => 20,      # The size of the entity number within a GUID
 };
 
-use namespace::clean;
-
 ## Entity "methods"
 
 my $version = sub ($e) { $e >> ENTITY_SHIFT };
@@ -120,7 +118,7 @@ sub clear ($self) {
 
 # Create a new entity
 sub create ( $self, @components ) {
-    croak 'Component must be a reference'
+    Carp::croak 'Component must be a reference'
         if List::Util::any { !ref } @components;
 
     my $guid = $self->{available}->$is_null
@@ -132,8 +130,8 @@ sub create ( $self, @components ) {
 }
 
 sub check ( $self, $guid, $type ) {
-    croak 'GUID must be defined' unless defined $guid;
-    croak 'Component name must be defined and not a reference'
+    Carp::croak 'GUID must be defined' unless defined $guid;
+    Carp::croak 'Component name must be defined and not a reference'
         if ! defined $type || ref $type;
 
     my $index  = $guid->$entity;
@@ -144,11 +142,11 @@ sub check ( $self, $guid, $type ) {
 
 # Add or replace a component for an entity
 sub add ( $self, $guid, @components ) {
-    croak 'GUID must be defined' unless defined $guid;
+    Carp::croak 'GUID must be defined' unless defined $guid;
 
     my $index = $guid->$entity;
     for my $component (@components) {
-        my $name = ref($component) || croak 'Component must be a reference';
+        my $name = ref($component) || Carp::croak 'Component must be a reference';
 
         #                                SPARSE  DENSE   COMPONENTS
         #                                      \   |    /
@@ -180,16 +178,16 @@ sub add ( $self, $guid, @components ) {
 # The public version of this method forwards to the "safe" flavour of the
 # private one
 sub get ( $self, $guid, @types ) {
-    croak 'GUID must be defined' unless defined $guid;
+    Carp::croak 'GUID must be defined' unless defined $guid;
 
-    croak 'Component name must be defined and not a reference'
+    Carp::croak 'Component name must be defined and not a reference'
         if List::Util::any { !defined || ref } @types;
 
     $self->$get( 0, $guid, @types );
 }
 
 sub delete ( $self, $guid, @types ) {
-    croak 'GUID must be defined' unless defined $guid;
+    Carp::croak 'GUID must be defined' unless defined $guid;
 
     unless (@types) {
         # Remove an entity and all its components
@@ -210,7 +208,7 @@ sub delete ( $self, $guid, @types ) {
         return;
     }
 
-    croak 'Component name must not be a reference'
+    Carp::croak 'Component name must not be a reference'
         if List::Util::any { ref } @types;
 
     for my $name (@types) {
@@ -243,7 +241,7 @@ sub delete ( $self, $guid, @types ) {
 # Checks if an entity identifier refers to a valid entity; that is, one that
 # has been created and not deleted.
 sub valid ( $self, $guid ) {
-    croak 'GUID must be defined' unless defined $guid;
+    Carp::croak 'GUID must be defined' unless defined $guid;
 
     my $pos = $guid->$entity;
     $pos < @{ $self->{entities} }
@@ -313,7 +311,7 @@ sub view ( $self, @types ) {
         while ( my ( $i, $e ) = each @{ $set->[DENSE] } ) {
             my $guid = $self->$add_version($e);
 
-            next unless all { $self->check( $guid => $_ ) } @rest;
+            next unless List::Util::all { $self->check( $guid => $_ ) } @rest;
 
             push @view, $guid => [
                 map {
@@ -352,9 +350,9 @@ sub _dump_entities ( $self, @types ) {
             print $fh sprintf "# %6s %5s %12X %s\n",
                 $set->[SPARSE][$_] // '---',
                 $set->[DENSE][$_]  // '---',
-                refaddr($component) // 0,
+                Scalar::Util::refaddr($component) // 0,
                 defined $component
-                    ? Dumper($component) =~ s/[\n\r]//gr : '---';
+                    ? Data::Dumper::Dumper($component) =~ s/[\n\r]//gr : '---';
         }
 
         print $fh "#\n" if $index++ < $#names;
@@ -363,4 +361,14 @@ sub _dump_entities ( $self, @types ) {
     $out unless $print;
 }
 
+# Clean our namespace
+delete $Game::Entities::{$_} for qw(
+    COMPONENTS
+    DENSE
+    ENTITY_MASK
+    ENTITY_SHIFT
+    SPARSE
+    VERSION_MASK
+);
+
 1;
